==> apache-rat-0.16.1-src.tar.bz2: apache-rat-0.16.1/apache-rat-core/src/test/java/org/apache/rat/analysis/matchers/SPDXMatcherTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 */
package org.apache.rat.analysis.matchers;

import static org.junit.jupiter.api.Assertions.assertEquals;

import org.apache.rat.analysis.IHeaderMatcher;
import org.apache.rat.analysis.IHeaderMatcher.State;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

public class SPDXMatcherTest {

    IHeaderMatcher target = SPDXMatcherFactory.INSTANCE.create("hello");

    @BeforeEach
    public void setup() {
        target.reset();
    }

    @Test
    public void testMatch() {
        assertEquals(State.i, target.currentState());
        assertEquals(State.i, target.matches("SPDX-License-Identifier: Apache-2"));
        assertEquals(State.i, target.currentState());
        assertEquals(State.t, target.matches("SPDX-License-Identifier: hello"));
        assertEquals(State.t, target.currentState());
        assertEquals(State.t, target.finalizeState());
        assertEquals(State.t, target.currentState());
        target.reset();
        assertEquals(State.i, target.currentState());
    }

    @Test
    public void testNoMatch() {
        assertEquals(State.i, target.currentState());
        assertEquals(State.i, target.matches("SPDX-License-Identifier: Apache-2"));
        assertEquals(State.i, target.currentState());
        assertEquals(State.i, target.matches("SPDX-License-Identifier: MIT"));
        assertEquals(State.i, target.currentState());
        assertEquals(State.f, target.finalizeState());
        assertEquals(State.f, target.currentState());
        target.reset();
        assertEquals(State.i, target.currentState());
    }

    @Test
    public void testTrueIsAlwaysTrue() {
        assertEquals(State.i, target.currentState());
        assertEquals(State.t, target.matches("SPDX-License-Identifier: hello"));
        assertEquals(State.t, target.currentState());
        assertEquals(State.t, target.matches("SPDX-License-Identifier: Apache-2"));
        assertEquals(State.t, target.currentState());
        assertEquals(State.t, target.finalizeState());
        assertEquals(State.t, target.currentState());
        target.reset();
        assertEquals(State.i, target.currentState());
    }
    
    @Test
    public void testResetClearsLastMatch() {
        
        assertEquals(State.i, target.currentState());
        assertEquals(State.t, target.matches("SPDX-License-Identifier: hello"));
        assertEquals(State.t, target.currentState());
        target.reset();
        assertEquals(State.i, target.currentState());
        assertEquals(State.i, target.matches("Something weird"));;
    }
}

==> apache-rat-0.17-src.tar.bz2: apache-rat-0.17/apache-rat-core/src/test/java/org/apache/rat/analysis/matchers/SPDXMatcherTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 */
package org.apache.rat.analysis.matchers;

import static org.junit.jupiter.api.Assertions.assertFalse;
import static org.junit.jupiter.api.Assertions.assertTrue;

import org.apache.rat.analysis.IHeaderMatcher;
import org.apache.rat.analysis.IHeaders;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

public class SPDXMatcherTest {

    final IHeaderMatcher target1 = SPDXMatcherFactory.INSTANCE.create("hello");
    final IHeaderMatcher target2 = SPDXMatcherFactory.INSTANCE.create("world");
    final IHeaderMatcher target3 = SPDXMatcherFactory.INSTANCE.create("goodbye");

    @BeforeEach
    public void setup() {
        target1.reset();
    }

    @Test
    public void testMatch() {
        String sb = SPDXMatcherFactory.LICENSE_IDENTIFIER + " world" + System.lineSeparator() +
                SPDXMatcherFactory.LICENSE_IDENTIFIER + " hello" + System.lineSeparator();

        IHeaders headers =  AbstractMatcherTest.makeHeaders(sb,null);

        assertTrue(target1.matches(headers));
        assertTrue(target2.matches(headers));
        assertFalse(target3.matches(headers));
        target1.reset();
    }
}
